This enhancement is to use the FilePath field in the loaded image
protocol to find the name of an image as a fallback for when the
loaded image device path protocol is not installed on the image handle.
This is necessary because the SMM core does not install the loaded
image device path protocol, so DP was displaying "Unknown Driver Name"
for every SMM driver.

Cc: Liming Gao <liming....@intel.com>
Cc: Daryl McDaniel <edk2-li...@mc2research.org>
Cc: Jaben Carsey <jaben.car...@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Star Zeng <star.z...@intel.com>
---
 PerformancePkg/Dp_App/DpUtilities.c | 13 ++++++++++---
 1 file changed, 10 insertions(+), 3 deletions(-)

diff --git a/PerformancePkg/Dp_App/DpUtilities.c 
b/PerformancePkg/Dp_App/DpUtilities.c
index ec5a524..b49844a 100644
--- a/PerformancePkg/Dp_App/DpUtilities.c
+++ b/PerformancePkg/Dp_App/DpUtilities.c
@@ -1,7 +1,7 @@
 /** @file
   Utility functions used by the Dp application.
 
-  Copyright (c) 2009 - 2015, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2009 - 2016, Intel Corporation. All rights reserved.<BR>
   This program and the accompanying materials
   are licensed and made available under the terms and conditions of the BSD 
License
   which accompanies this distribution.  The full text of the license may be 
found at
@@ -221,6 +221,9 @@ GetNameFromHandle (
   CHAR8                       *BestLanguage;
   EFI_COMPONENT_NAME2_PROTOCOL      *ComponentName2;
 
+  Image = NULL;
+  LoadedImageDevicePath = NULL;
+  DevicePath = NULL;
   BestLanguage     = NULL;
   PlatformLanguage = NULL;
 
@@ -307,9 +310,13 @@ GetNameFromHandle (
                   );
   if (!EFI_ERROR (Status) && (LoadedImageDevicePath != NULL)) {
     DevicePath = LoadedImageDevicePath;
+  } else if (Image != NULL) {
+    DevicePath = Image->FilePath;
+  }
 
+  if (DevicePath != NULL) {
     //
     // Try to get image GUID from LoadedImageDevicePath protocol
     //
     NameGuid = NULL;
     while (!IsDevicePathEndType (DevicePath)) {
@@ -356,7 +363,7 @@ GetNameFromHandle (
       //
       // Method 5: Get the name string from image DevicePath
       //
-      NameString = ConvertDevicePathToText (LoadedImageDevicePath, TRUE, 
FALSE);
+      NameString = ConvertDevicePathToText (DevicePath, TRUE, FALSE);
       if (NameString != NULL) {
         StrnCpyS (
           mGaugeString,
@@ -307,9 +310,13 @@ GetNameFromHandle (
     //
-    // Try to get image GUID from LoadedImageDevicePath protocol
+    // Try to get image GUID from image DevicePath
     //
     NameGuid = NULL;
-- 
2.7.0.windows.1

_______________________________________________
edk2-devel mailing list
edk2-devel@lists.01.org
https://lists.01.org/mailman/listinfo/edk2-devel

Reply via email to